@@ -45,11 +45,3 @@ class Artist(object):
 
     def update_data(self):
         raise NotImplementedError
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-    pass
